<?php
	/*
	* 2018 - VEGA Informatique
	*
	* NOTICE OF LICENSE
	*
	* This source file is subject to the Open Software License (OSL 3.0)
	* that is bundled with this package in the file LICENSE.txt.
	* It is also available through the world-wide-web at this URL:
	* http://opensource.org/licenses/osl-3.0.php
	*
	* DISCLAIMER
	*
	* Do not edit or add to this file if you wish to upgrade PolarisLink to newer
	* versions in the future. 
	*
	*  @author VEGA Informatique <contact@vega-info.fr>
	*  @copyright  2018 VEGA Informatique
	*  @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
	*/

	require_once(_PS_ROOT_DIR_ . "/modules/polarislink/classes/PolarisLinkImportBase.php");
	
	/*
	 * ex. : <category ref="xx" type="collection">
				<name/>
				<description/>
			</category>
	 */
	class PolarisLinkImport_category extends PolarisLinkImportBase 
	{	
		private $Categories = null;
		private $CategoriesById = null;
	
		protected function OnInit()
		{
			parent::OnInit();
			
			$this->setCache(new PolarisLinkExtRefCache($this->Link->LinkID, "category"));
		}
		
		public function GetCategories()
		{
			if ($this->Categories == null)
			{
				// Nous devons charger les catégories (pour aller plus vite)
				$this->Categories = array();
				
				foreach (Db::getInstance(_PS_USE_SQL_SLAVE_)->executeS('
								SELECT c.id_category, c.id_parent, cl.name, c.active
								FROM `'._DB_PREFIX_.'category` c
								'.Shop::addSqlAssociation('category', 'c').'
								LEFT JOIN `'._DB_PREFIX_.'category_lang` cl ON (c.`id_category` = cl.`id_category`'.Shop::addSqlRestrictionOnLang('cl').' AND `id_lang` = '.$this->Link->LangID.")", true, false
							) as $category)
					$this->Categories[] = $category;
			}
			
			return $this->Categories;
		}
		
		public function GetCategoriesById()
		{
			if ($this->CategoriesById == null)
			{
				$this->CategoriesById = array();
				foreach ($this->GetCategories() as $category)
					$this->CategoriesById[$category["id_category"]] = $category;
			}
			return $this->CategoriesById;
		}		
		
		public function InvalidCache()
		{
			$this->Categories = null;
			$this->CategoriesById = null;
		}
		
		public function getParentCategoryId($data, $mainRoot = null, $parentTagName = "category", $parentType = null)
		{
			$parentId = $mainRoot;
			if (!empty($data->$parentTagName))
			{
				// Il y a un parent, on vérifie qu'il existe ...
				$psId = $this->ImportData($data->$parentTagName, $parentTagName, $parentType, $parentType);
				if (empty($psId))
					throw new Exception(sprintf("Impossible de trouver la racine de la catégorie (noeud cherché: %s)", $parentTagName));
				return $psId;
			}
			else
			{
				if ($mainRoot == NULL)
					throw new Exception("Aucun parent spécifié pour la catégorie alors qu'attendu");
			}
			
			return $mainRoot;
		}
		
		public function getCategory($polarisRef, $names, $parentId)
		{		
			$cache = $this->getCache("pr_category");
			return $cache->get($polarisRef);
		}
		
		public function getOrCreateCategory($polarisRef, $names, $parentId)
		{		
			$cache = $this->getCache("pr_category");
			$psId = $cache->get($polarisRef);
			if (empty($psId))
			{
				// On cherche la catégorie par son nom ...
				foreach ($names as $langId => $name)
				{
					$row = Category::searchByNameAndParentCategoryId($langId, $name, $parentId);
					if (!empty($row))
					{
						$psId = $row["id_category"];
						break;
					}
				}
				
				if (empty($psId))
				{					
					$obj = new Category();					
					$obj->id_parent = $parentId;
					$obj->name = $this->AutoFillEmptyLangValue($names, $polarisRef);
					
					$obj->link_rewrite = array();
					foreach ($names as $langId => $name)
					{
						$propo = trim(Tools::link_rewrite($name));
						
						if (empty($propo))
							$propo = Tools::link_rewrite("inconnu-".$polarisRef);
						
						$obj->link_rewrite[$langId] = $propo;						
					}

					// référence non trouvée, création ...
					$parentCategory = new Category($parentId);
					$obj->active = $parentCategory->active;	
					$obj->save();
					
					$psId = $obj->id;
					$this->InvalidCache();
				}
				
				$cache->set($polarisRef, $psId);
			}
			
			return $psId;
		}
				
		protected function GetCategoryInfoForType($strType)
		{		
			switch ($strType)
			{
				case "ray": return array("CPR" => "ray %s", "root" => $this->Link->CategoryForRFS);
				case "family": return array("CPR" => "fam %s", "root" => NULL);
				case "rfs": return array("CPR" => "rfs %s", "root" => NULL);
				case "c1": return array("CPR" => "c1 %s", "root" => $this->Link->CategoryForCategory1);
				case "c2": return array("CPR" => "c2 %s", "root" => $this->Link->CategoryForCategory2);
				case "c3": return array("CPR" => "c3 %s", "root" => $this->Link->CategoryForCategory3);
				case "c4": return array("CPR" => "c4 %s", "root" => $this->Link->CategoryForCategory4);
				case "collection": return array("CPR" => "col %s", "root" => $this->Link->CategoryForCollection);
				case "tag": return array("CPR" => "tag %s", "root" => NULL);
				case "season": return array("CPR" => "ssn %s", "root" => $this->Link->CategoryForSeason);
				case "grtag": return array("CPR" => "gtg %s", "root" => $this->Link->CategoryForTags);
				case NULL:
				case "":
					return array("CPR" => "%s", "root" => (int)Configuration::get('PS_ROOT_CATEGORY'));
				default:
					throw new Exception(sprintf("Catégorie de type « %s » inconnue", $strType));
			}
		}
		
		protected function ConvertPolarisRef($categoryInfoType, $polarisRef)
		{
			return sprintf($categoryInfoType["CPR"], $polarisRef);
		}
		
		public function ImportData($data, $parentTagName = "category", $categoryType = null, $parentType = null)
		{
			if (!$this->Link->OPT_ALLOW_I_CATALOG)
				return;	// Rien à faire ici dans ce cas là !
			
			// On se positionne sur le bon shop !
			$this->SetCatalogContext();
			
			// Avons nous la référence Polaris ?
			$infoTypeCategory = $this->GetCategoryInfoForType(empty($categoryType) ? (string) $this->GetMandatory($data, "", "type") : $categoryType);
			$polarisRef = $this->ConvertPolarisRef(
								$infoTypeCategory,
								(string) $this->GetMandatory($data, "", "ref"));
								
			// Localisation de la marque
			$cache = $this->getCache("pr_category");
			$psId = $cache->get($polarisRef);
			// Activé ?
			$deleted = (string) $this->GetOptional($data, "", "deleted", "0");
			
			if (!$deleted)
			{			
				$obj = new Category($this->getOrCreateCategory($polarisRef, checkCategoryName($this->getLgProperty($data->name, true)), 
							$this->getParentCategoryId($data, $infoTypeCategory["root"], $parentTagName, $parentType)));
			
				$origin = $this->getPSObjHash($obj);
			
				if (count($data->name))
					$this->updateLgProperty($obj, "name", $data->name, NULL, false, 'checkCategoryName');
				
				if ($this->Link->OPT_ALLOW_I_DESCRIPTIONS && count($data->description) > 0)				
					$this->updateLgProperty($obj, "description", $data->description);				
				
				if ($this->Link->OPT_ALLOW_I_MDESCRIPTIONS && count($data->meta) > 0)
					$this->updateLgProperty($obj, "meta_description", $data->meta);
				
				// le pont ne doit pas réactiver pas des catégories masquées intentionnellement
				// $obj->active = true;
				
				if ($this->Link->OPT_ALLOW_I_PHOTOS && count($data->photos) > 0)
					$this->ImportPhotoLogo("catégorie", _PS_CAT_IMG_DIR_, "categories", "category", $obj, (string) $data->photos);
				
				// On sauve uniquement si qqchose a été changé !
				if ($this->getPSObjHash($obj) != $origin)
					$obj->save();

				$psId = $obj->id;
			}
			else if (!empty($psId))
			{		
				// Element non publié mais en cours sur le site, on active ou pas, selon
				$obj = new Category($psId);
				if ($obj->active)
				{
					$obj->active = false;
					$obj->save();
				}
			}
			
			return $psId;
		}
		
		protected function OnImportData($data)
		{
			$this->ImportData($data);
		}
	}
	