<?php
	/*
	* 2018 - VEGA Informatique
	*
	* NOTICE OF LICENSE
	*
	* This source file is subject to the Open Software License (OSL 3.0)
	* that is bundled with this package in the file LICENSE.txt.
	* It is also available through the world-wide-web at this URL:
	* http://opensource.org/licenses/osl-3.0.php
	*
	* DISCLAIMER
	*
	* Do not edit or add to this file if you wish to upgrade PolarisLink to newer
	* versions in the future. 
	*
	*  @author VEGA Informatique <contact@vega-info.fr>
	*  @copyright  2018 VEGA Informatique
	*  @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
	*/

	require_once(_PS_ROOT_DIR_ . "/modules/polarislink/classes/PolarisLinkImportBase.php");
	require_once(_PS_ROOT_DIR_ . "/modules/polarislink/classes/PolarisLinkImport_customer.php");
	
	/*
	 * ex. : 
	 <voucher ref="2800010002135" for="41385985@test.fr">
        <name>Création Automatique : 21/07/2017</name>
        <emit_date>2017-07-21</emit_date>
        <valid_until>2018-07-21</valid_until>
        <amount>185.00</amount>
        <currency code="eur" symb="€">euros</currency>
    </voucher>
	 */
	class PolarisLinkImport_voucher extends PolarisLinkImportBase 
	{
		private $_CurrenciesBySign = array();
		private $_CurrenciesByCode = array();
		private $_CurrenciesByName = array();
		
		public function OnInit()
		{
			parent::OnInit();
						
			foreach(Currency::getCurrencies() as $currency)
			{
				$id = $currency["id_currency"];
				$this->_CurrenciesBySign[strtolower($currency["sign"])] = $id;
				$this->_CurrenciesByCode[strtolower($currency["iso_code"])] = $id;
				$this->_CurrenciesByName[strtolower($currency["name"])] = $id;
			}	
		}		
		
		private function UpdateData($cartRule, $data)
		{
			$this->updateLgProperty($cartRule, "name", $data->name, "Coupon de réduction", true);
			
			// Recherche du client
			$mail = (string) $data["for"];
			if (!empty($mail))
			{
				$id = PolarisLinkImport_customer::GetCustomerIdForMail($mail, $this->Link->OPT_ALLOW_I_CUSTOMERS);
				if (empty($id))
					return false;
				
				$cartRule->id_customer = $id;
			}
			
			$this->updateProperty($cartRule, "date_from", $data->emit_date);
			$this->updateProperty($cartRule, "date_to", $data->valid_until, 
										date_format(date_add(date_create(), date_interval_create_from_date_string('10 years')), "Y-m-d"));
			$data->date_to = (string) $data->valid_until;

			$amount = (string) $data->amount;
			if (!empty($amount))
			{
				$cartRule->reduction_percent = NULL;
				$cartRule->reduction_amount = floatval($amount);
				$cartRule->reduction_tax = 1;
				
				// Recherche de la monnaie ...
				$cartRule->reduction_currency = $this->JobManager->getCurrencyFor((string) $data->currency["code"], (string) $data->currency["symb"], (string)$data->currency);
			}
			else 
			{
				$percentage = (string) $data->percentage;
				if (!empty($percentage))
				{
					$cartRule->reduction_percent = floatval($percentage);
					$cartRule->reduction_amount = NULL;
					$cartRule->reduction_tax = NULL;
					$cartRule->reduction_currency = NULL;
				}
			}
				
			$cartRule->active = 1;
			$cartRule->highlight = (!empty($mail)) ? 1 : 0;
			$cartRule->partial_use = 0;
			$cartRule->priority = 2;
			$cartRule->quantity = 1;
			$cartRule->quantity_per_user = 1;				
			
			return true;
		}
		
		protected function OnImportData($data)
		{
			// Avons nous la référence ?
			$ref = (string) $data["ref"];
			if (empty($ref))
				throw new Exception("aucune référence spécifiée pour le bon");
				
			$type = (string) $data->type;
			if ($type !== "" && $type !== null)
			{
				switch ($type)
				{
					case "0": // chèque cadeau
					case "1": // bon de remise
						if (!$this->Link->OPT_ALLOW_I_VOUCHERS_OFFERS)						
							return;
						break;
					case "2": // avoir					
						if (!$this->Link->OPT_ALLOW_I_VOUCHERS_ASSETS)
							return;
						break;

					case "3": // arrhes
					case "4": // acompte
					default:
						return;	// Pas d'importation de ce type de bon !
				}
			}
			else
			{
				if (!$this->Link->OPT_ALLOW_I_VOUCHERS_ASSETS || !$this->Link->OPT_ALLOW_I_VOUCHERS_OFFERS)
					return;	// Pas d'importation de bons !					
			}

			$deleted = (int) $data["deleted"];
			
			if (!$deleted)
			{
				// Si le bon n'est pas effacé, mais qu'il n'est plus valable, inutile de l'importer !
				$expiration = (string) $data->valid_until;
				if (!empty($expiration) && $expiration < date("Y-m-d 00:00:00"))
					$deleted = true;
			}
			
			// On localise la règle de panier symbolisant le coupon de réduction
			$id = CartRule::getIdByCode($ref);
			if (empty($id) && $deleted)
				return;	// Existe pas, en même temps, il faut le supprimer, donc on s'arrête là...
			
			// On charge ou créer la règle			
			if (empty($id))
			{
				// On créer la règle
				$cartRule = new CartRule();
				$cartRule->code = $ref;
								
				// On sauve les modifications
				if ($this->UpdateData($cartRule, $data))
					$cartRule->save();
			}
			else
			{
				// On modifie la règle
				$cartRule = new CartRule($id);
				
				if ($deleted)
				{
					// On doit supprimer le voucher
					$cartRule->delete();
				}
				else
				{
					// On sauve les modifications
					$origin = $this->getPSObjHash($cartRule);
					if ($this->UpdateData($cartRule, $data))
					{
						if ($this->getPSObjHash($cartRule) != $origin)
							$cartRule->save();
					}
				}
			}
		}
	}
	