<?php
	/*
	* 2018 - VEGA Informatique
	*
	* NOTICE OF LICENSE
	*
	* This source file is subject to the Open Software License (OSL 3.0)
	* that is bundled with this package in the file LICENSE.txt.
	* It is also available through the world-wide-web at this URL:
	* http://opensource.org/licenses/osl-3.0.php
	*
	* DISCLAIMER
	*
	* Do not edit or add to this file if you wish to upgrade PolarisLink to newer
	* versions in the future. 
	*
	*  @author VEGA Informatique <contact@vega-info.fr>
	*  @copyright  2018 VEGA Informatique
	*  @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
	*/

	require_once(_PS_ROOT_DIR_ . "/modules/polarislink/classes/PolarisLinkImportBase.php");
	
	/*
	 * ex. : <warehouse ref="1"><name/><address1/><address2/><postcode/><city/><country/><phone/><phone_mobile/></warehouse>
	 */
	class PolarisLinkImport_warehouse extends PolarisLinkImportBase 
	{
		public function OnInit()
		{
			parent::OnInit();
			
			$this->setCache(new PolarisLinkCache("warehouse", 
													"SELECT reference AS k, id_warehouse AS v FROM "._DB_PREFIX_."warehouse", NULL, "Warehouse"));
		}
		
		public function getOrCreateWarehouse($code, $name = null)
		{
			$warehouse = $this->getCache("warehouse")->get($code);
			if (empty($warehouse))
			{
				// Création de l'entrepôt
				$address = new Address();
				
				$address->company = "";
				$address->alias = "Adresse principale";
				$address->lastname = "Entrepôt";
				$address->firstname = "Entrepôt";
				$address->address1 = "n.c.";
				$address->postcode = "0";
				$address->city = "n.c.";
				$address->id_country = Country::getIdByName(null, "France");
				$address->save();

				$warehouse = new Warehouse();
				$warehouse->id_address = $address->id;
				$warehouse->reference = $code;
				$warehouse->name = $this->FirstNonEmpty($name, "Magasin code ".$code);
				
				$context = Context::getContext();
				$warehouse->id_employee = $context->employee->id;
				$warehouse->id_currency = Currency::getDefaultCurrency()->id;
				$warehouse->management_type = 'WA';
				$warehouse->deleted = false;
				
				$warehouse->save();
				
				$address->id_warehouse = $warehouse->id;
				$address->save();
				
				$this->getCache("warehouse")->set($code, $warehouse);
			}
			
			return $warehouse;
		}
		
		protected function OnImportData($data)
		{
			// Pas besoin d'entrepôts ?
			if (!Configuration::get('PS_ADVANCED_STOCK_MANAGEMENT') || !$this->Link->OPT_USE_ADV_STOCK)
				return;
			
			// Avons nous la référence ?
			$ref = (string) $data["code"];
			if ($ref !== "0" && empty($ref))
				throw new Exception("aucune référence spécifiée pour l'entrepôt");

			// Création ou modification de l'entrepôt
			$name = $this->FirstNonEmpty((string) $data->name, "Magasin code ".$ref);			
			$warehouse = $this->getOrCreateWarehouse($ref, $name);
			
			// Chargement de l'adresse ...
			$addr = $warehouse->id_address ? new Address($warehouse->id_address) : new Address();
			$origin = $this->getPSObjHash($addr);
				
			$country = ucwords(strtolower(trim((string) $data->country)));

			$this->updateProperty($addr, "address1", $data->address1, "n.c.");
			$this->updateProperty($addr, "address2", $data->address2);
			$this->updateProperty($addr, "postcode", $data->postcode, "0");
			$this->updateProperty($addr, "city", $data->city, "n.c.");						
			$this->updateProperty($addr, "id_country", !empty($country) ? Country::getIdByName(null, $country) : Country::getIdByName(null, "France"), Country::getIdByName(null, "France"));
			
			$this->updateProperty($addr, "phone", $data->phone, "");
			$this->updateProperty($addr, "phone_mobile", $data->phone_mobile, "");
			$this->updateProperty($addr, "alias", $data->name, "principale");

			if (!$addr->id)
			{
				$addr->company = "";
				$addr->lastname = "warehouse";
				$addr->firstname = "warehouse";				
			}
			if ($this->getPSObjHash($addr) != $origin)
				$addr->save();
								
			$origin = $this->getPSObjHash($warehouse);
			$warehouse->id_address = $addr->id;
			
			$this->updateProperty($warehouse, "reference", $ref);
			$this->updateProperty($warehouse, "name", $name);	
			$this->updateProperty($warehouse, "deleted", "0");	
			
			if (!$warehouse->id)
			{
				$context = Context::getContext();
				$warehouse->id_employee = $context->employee->id;
				$warehouse->id_currency = Currency::getDefaultCurrency()->id;
				$warehouse->management_type = 'WA';
			}
			
			if ($this->getPSObjHash($warehouse) != $origin)
				$warehouse->save();
			
			if (!$addr->id_warehouse)
			{
				$addr->id_warehouse = $warehouse->id;
				$addr->save();
			}
		}
	}
	