<?php
	/*
	* 2018 - VEGA Informatique
	*
	* NOTICE OF LICENSE
	*
	* This source file is subject to the Open Software License (OSL 3.0)
	* that is bundled with this package in the file LICENSE.txt.
	* It is also available through the world-wide-web at this URL:
	* http://opensource.org/licenses/osl-3.0.php
	*
	* DISCLAIMER
	*
	* Do not edit or add to this file if you wish to upgrade PolarisLink to newer
	* versions in the future. 
	*
	*  @author VEGA Informatique <contact@vega-info.fr>
	*  @copyright  2018 VEGA Informatique
	*  @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
	*/

	if (!defined('_PS_VERSION_'))
		exit;
			
	require_once(_PS_ROOT_DIR_ . "/modules/polarislink/classes/PolarisLinkAPI.php");
	require_once(_PS_ROOT_DIR_ . "/modules/polarislink/classes/PolarisLinkJobManager.php");
		
	/*
	 * Obtient des informations sur les travaux en cours
	 * jobId => télécharge le job
	 * list => liste les travaux
	 * clear => supprime les travaux (que le dernier, ou all, tous)
	 *
	 */
	class PolarisLinkAPI_DownloadJobModuleFrontController extends PolarisLinkAPI
	{		
		protected function runAPI()
		{
			$jobsManager = new PolarisLinkJobManager($this->Link);
			
			if (!isset($_REQUEST["jobId"]) || empty($_REQUEST["jobId"]))
			{
				if (isset($_REQUEST["list"]))
				{
					// Liste des travaux
					$jobs = array();
					
					$paths = array(
									$jobsManager->getQueuePath(),
									$jobsManager->getArchivesPath()
								);
								
					foreach ($paths as $path)
					{
						foreach (scandir($path, SCANDIR_SORT_ASCENDING) as $filename)
						{
							if (strlen($filename) > 3)
								$jobs[] = $filename;
						}
					}
					
					header("Content-Type: application/json");
					echo json_encode($jobs, JSON_PRETTY_PRINT);
				}
				else if (isset($_REQUEST["clear"]))
				{
					$deleted = array();
					
					if (isset($_REQUEST["all"]))
					{
						$paths = array(
									$jobsManager->getQueuePath(),
									$jobsManager->getArchivesPath()
								);
								
						foreach ($paths as $path)
						{
							foreach (scandir($path, SCANDIR_SORT_ASCENDING) as $filename)
							{
								if (strlen($filename) > 3)
								{									
									$deleted[] = $filename;
									unlink($path."/".$filename);
								}
							}
						}
					}
					else
					{
						// Suppression du travail en cours !
						$jobs = PolarisLinkJobs::loadAll($this->Link->LinkID);
						if ($jobs != null)
						{
							foreach ($jobs as $job)
							{
								$deleted[] = $job->job;
								unlink($jobsManager->getQueuePath()."/".$job->job);
								break;
							}
						}
					}
					
					header("Content-Type: application/json");
					echo json_encode($deleted, JSON_PRETTY_PRINT);
				}
				else
				{
					http_response_code(404);
					echo "Can i have the jobId ?";
				}
			}
			else
			{
				$jobId = $_REQUEST["jobId"];
				if (strpos($jobId, ".") !== false)
					throw new Exception("not a valid jobId");
				if (strpos($jobId, "~") !== false)
					throw new Exception("not a valid jobId");
				
				// On cherche le travail dans le flux commun, ou si non trouvé dans les archives
				$filename = "";
								
				$paths = array(
								$jobsManager->getQueuePath(),
								$jobsManager->getArchivesPath()
							);
							
				foreach ($paths as $path)
				{
					$test = $path."/".$jobId;
					if (file_exists($test))
					{
						$filename = $test;
						break;
					}
				}
				
				
				if (empty($filename))
				{
					http_response_code(404);
					echo sprintf("jobId %s not found", $_REQUEST["jobId"]);
				}
				else
				{
					if ($jobsManager->testGZfile($filename))
					{
						header('Content-Type: application/gzip');
						header('Content-Disposition: attachment; filename="'.$jobId.'.txt.gz');
					}
					else
					{
						header('Content-Type: text/plain; charset=utf-8');
						header('Content-Disposition: attachment; filename="'.$jobId.'.txt');
					}														
					print file_get_contents($filename);
				}
			}
		}
	}
 