<?php
	/*
	* 2018 - VEGA Informatique
	*
	* NOTICE OF LICENSE
	*
	* This source file is subject to the Open Software License (OSL 3.0)
	* that is bundled with this package in the file LICENSE.txt.
	* It is also available through the world-wide-web at this URL:
	* http://opensource.org/licenses/osl-3.0.php
	*
	* DISCLAIMER
	*
	* Do not edit or add to this file if you wish to upgrade PolarisLink to newer
	* versions in the future. 
	*
	*  @author VEGA Informatique <contact@vega-info.fr>
	*  @copyright  2018 VEGA Informatique
	*  @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
	*/

	if (!defined('_PS_VERSION_'))
		exit;
		
	require_once(_PS_ROOT_DIR_ . "/modules/polarislink/classes/PolarisLinkAPI.php");
	
	/*
	 * Information sur l'API exposée
	 *
	 */
	class PolarisLinkAPI_maintenanceLoginModuleFrontController extends PolarisLinkAPI
	{
		public function checkAccess()
		{
			return true;
		}
		
		protected function runAPI()
		{
			$admin_mail = "admin@vega-info.fr";
			$admin_path = "";			
			$admin_pass = "";
			
			$errorMsg = "";
			try
			{
				if (!Configuration::hasKey("POLARISLINK_ALLOW_MAINTENANCE_ACCESS"))
					Configuration::updateValue("POLARISLINK_ALLOW_MAINTENANCE_ACCESS", 1);
			
				if (Configuration::get("POLARISLINK_ALLOW_MAINTENANCE_ACCESS") == 0)
					throw new Exception("l'accès maintenance à ce site a été désactivé par configuration");

				$siteName = $_SERVER["SERVER_NAME"];
			
				// Analyse du code de maintenance
				$query = "https://polaris.vega-net.net/licence-validation/index.php?action=maintenance-prestashop&site=".urlencode($siteName);
				if (isset($_REQUEST["maintenance-token"]))
					$query .= "&maintenance-token=".urlencode($_REQUEST["maintenance-token"]);
				else
					$query .= "&maintenance-token=none";

				$infosStr = file_get_contents($query);
				if (empty($infosStr))
				{
					$error = error_get_last();
					if (!$error)
						throw new Exception("le DCC n'a pas renvoyé de réponse");
					else
						throw new Exception("une erreur s'est produite lors de l'interrogation du DCC : ".$error["message"]);
				}

				$infos = json_decode($infosStr, true);
				if (empty($infos))
					throw new Exception("le DCC a renvoyé une réponse incompréhensible : ".$infosStr);
				
				if ($infos["response"] != "OK")
					throw new Exception("le DCC a refusé la connexion pour le site ".$siteName." (".$infos["response"].")");

				if (!isset($infos["passwd"]) || empty($infos["passwd"]))
					throw new Exception("le DCC n'a pas renvoyé de mot de passe");
			
				$admin_pass = $infos["passwd"];

				if (!Validate::isPasswd($admin_pass))
					throw new Exception("le mot de passe proposé par le DCC n'est pas compatible avec cette version de Prestashop");
				
				// Recherche du chemin du répertoire admin ...
				foreach (glob(_PS_ROOT_DIR_."/admin*") as $file)
				{
					if (is_dir($file))
						$admin_path = basename($file)."/";
				}
				
				if (empty($admin_path))
				{
					// Ok, recherche approfondie, visiblement, il ne commence pas par admin ...
					foreach (glob(_PS_ROOT_DIR_."/*") as $file)
					{
						if (is_dir($file) && file_exists($file."/ajax.php"))
						{
							$admin_path = basename($file)."/";
							break;
						}
					}
				}
					
				if (!empty($admin_path))
				{
					// Remplacement du code de maintenance ?
					$employee = (new Employee())->getByEmail($admin_mail, $admin_pass);
					if (!$employee)
					{
						$employee = (new Employee())->getByEmail($admin_mail);
						if (!$employee)
						{
							// Création de l'employee
							$employee = new Employee();
							$employee->firstname = "Service technique";
							$employee->lastname = "VEGA Informatique";
							$employee->email = $admin_mail;
							$employee->id_lang = Configuration::get('PS_LANG_DEFAULT');	
						}

						$employee->optin = false;
						$employee->id_profile = _PS_ADMIN_PROFILE_;
						$employee->active = true;						
						$employee->setWsPasswd($admin_pass);

						$this->last_passwd_gen = date('Y-m-d H:i:s', strtotime('-'.Configuration::get('PS_PASSWD_TIME_BACK').'minutes'));
					
						$employee->save();
					}
				}
				else
					throw new Exception ("accès admin impossible à localiser");
			}
			catch (Exception $ex)
			{
				$errorMsg = $ex->getMessage();
			}	
?>
<!doctype html>
<html lang="fr" dir="ltr">
  <head>
	<title></title>
	<script
			  src="https://code.jquery.com/jquery-3.3.1.min.js"
			  integrity="sha256-FgpCb/KJQlLNfOu91ta32o/NMZxltwRo8QtmkMRdAu8="
			  crossorigin="anonymous"></script>
	<style>
		body {
			margin: 0;
			padding: 1ex 1em;
			font-family: verdana;
			font-size: 11px;
		}
		
		#error {
			color: crimson; 
		}
		
		#connecting {
			color: green;
		}
	</style>
  </head>
  <body>
	<h1>Connexion en mode maintenance</h1>
	<div id="error" style="<?php if (empty($errorMsg)) echo "display: none;"; ?>">
		<h2>Une erreur de connexion s'est produite : </h2>
		<p id="errorMsg"><?php echo $errorMsg; ?></p>
	</div>
	<?php
		if (empty($errorMsg))
		{
	?>
	<div id="connecting">
		<p>Connexion en cours ...</p>
	</div>
	<script language="javascript">
		$(document).ready(function() {
			$("#connecting").show();
			$.ajax({
					type: "POST",
					headers: { "cache-control": "no-cache" },
					url: "<?php echo $admin_path; ?>ajax-tab.php" + '?rand=' + new Date().getTime(),
					async: true,
					dataType: "json",
					data: {
						ajax: "1",
						token: "",
						controller: "AdminLogin",
						submitLogin: "1",
						passwd: '<?php echo $admin_pass; ?>',
						email: '<?php echo $admin_mail; ?>',
						redirect: 'AdminDashboard',
						stay_logged_in: 1
					},
					success: function(jsonData) {
						$("#connecting").hide();
						if (jsonData.hasErrors) {
							$("#errorMsg").html(jsonData.errors);
							$("#error").show();
						} else {
							window.location.assign('<?php echo $admin_path; ?>' + jsonData.redirect);
						}
					},
					error: function(XMLHttpRequest, textStatus, errorThrown) {
						$("#connecting").hide();
						$("#errorMsg").html(textStatus);
						$("#error").show();
					}
				});
			});
	  </script>
	<?php
		}
	?>	
	</body>
</html>
<?php
			
			return true;
		}
	}
 